Phylodev
========

Creates a nixos-container suitable for developments and testing of phyloalps. This requires a NixOS as the base system.

There are 3 parts:

* A nixos configuration, which is the base NixOS system of the container
* A script "init-phylodb-container.sh", to run as root, to launch and configure the container
* A script "store/init.sh" which is called inside the container, this is where most of the phyloalps configuration is done

The result is a running nixos-container with a devel/test phyloalps application running inside.

There's another container (phylotest) for running the tests (see bellow).

Installing and building the phylodb container:
----------------------------------------------
* Into the file `/etc/nixos/configuration.nix` of your NixOS host (as root), add the container configuration as an imported file:
  
  ```
  imports =
  [ # Include the results of the hardware scan.
    ./hardware-configuration.nix
    # Include containers configurations
    ./phylodb-container.nix
  ];
  ```
* Into the file `/etc/nixos/configuration.nix` of your NixOS host (as root), add a host entry for the phylodev fake domain:
  
  ```
  networking.hosts = {                               
   "127.0.0.1" = [ "localhost" "data.phylodev.org" ];
   "::1" = [ "localhost" ];                          
   };                                                 
  ```

* Copy the container configuration file (as root):
  
  ```
  cp phylodb-container.nix /etc/nixos/
  ```  
* Rebuild your NixOS for the container creation:
 
  ```
  nixos-rebuid switch
  ```

* Clone phylodb and phylodump (for example into `~/git/phylodb` and `~/git/phylodump`) 
* Check that you don't have any local http server running on your host (or it will conflict with the phylodev one)

* Launch the initialization script that will start the container and finalize the phylodb installation:

  ```
  sudo ./init-phylodb-container.sh ~/git/phylodb ~/git/phylodump
  ```
  
* Connect your browser to http://data.phylodev.org (the default login is "admin" and the password is "phylodev").
  
* If necessary, you can log in to the container as root:

  ```
  sudo nixos-container root-login phylodb
  ```

* To wipe the container (for restarting the setup process):

  ```
  sudo nixos-container stop phylodb
  sudo rm -rf /var/lib/containers/phylodb
  ```

Tests
-----
* Into the file `/etc/nixos/configuration.nix` of your NixOS host (as root), add an include of the file for the phylotest container:
  
  ```
  imports =
  [ # Include the results of the hardware scan.
    ./hardware-configuration.nix
    # Include containers configurations
    ./phylodb-container.nix
    ./phylotest-container.nix
  ];
  ```

* Copy the container configuration file (as root):
  
  ```
  cp phylotest-container.nix /etc/nixos/

 ```  
* Rebuild your NixOS for the container creation:
 
  ```
  nixos-rebuid switch
  ```
* Start and finalize the tests container

  ```
  sudo ./init-phylotest-container.sh
  ```
 
Running the tests
-----------------

The `run-tests.sh` script may be used to start the tests. It will create the phylodb and phylotest containers if they are not already running; so if your only goal is to run the tests, you can directly start this script after the installation of the containers into your system (ie copy `phylodb-container.nix` and `phylotest-container.nix` files into /etc/nixos and rebuild).

The tests are written in python, with the *webtest* module into the `store/phylo-webtests.py` file.

Example:
```
sudo ./run-tests.sh ~/git/phylodb ~/git/phylodump
```

And if you need to rebuild the phylodb container with changes you've made into your local copy, just stop the container and re-run the script:
```
sudo nixos-container stop phylodb
sudo ./run-tests.sh ~/git/phylodb ~/git/phylodump
```
