{ config, pkgs, ... }:
{
  containers.phylodb =
    { config =
      { config, pkgs, ... }:
      {

        environment.systemPackages = with pkgs; [
          coreutils
          findutils
          su
          vim
          postgresql
          postgis
          gdal
          geos
          proj
          sass
          traceroute
          git
          wget
          unzip
          (python36.withPackages(ps: with ps; [pip virtualenv psycopg2 urllib3 requests]))
        ];

         networking.hosts = {
           "127.0.0.1" = [ "localhost" "data.phylodev.org" ];
           "::1" = [ "localhost" ];
         };

        networking.nat.enable = true;
        services.openssh.enable = true;
        services.postgresql = {
          enable = true;
          package = pkgs.postgresql;
          authentication = "local all all ident";
          extraPlugins = [ pkgs.postgis ];
          initialScript = pkgs.writeText "backend-initScript" ''
            CREATE USER phyloalps WITH PASSWORD 'phyloalps';
            CREATE DATABASE browser_db OWNER phyloalps;
            CREATE DATABASE editor_db OWNER phyloalps;
          '';
        };

        users.extraUsers.phyloalps = {
          isNormalUser = true;
        };

        services.httpd = {
          enable = true;
          package = pkgs.apacheHttpd;
          adminAddr = "info@phyloalps.org";
          hostName = "localhost";
          logPerVirtualHost = true;
          extraModules = ["proxy" "proxy_http" "cache"];
          virtualHosts = [
            {
               hostName = "data.phylodev.org";
               documentRoot = "/var/lib/phyloalps/phylodb";
               extraConfig = ''
 
               ProxyPassReverse / http://localhost:8888/

               RewriteEngine on
               RewriteRule ^/\.well-known/?(.*)$ http://data.phylodev.org/static/%{REQUEST_URI} [L,P]
               RewriteRule ^/static/?(.*)$ - [L,P]
               RewriteRule ^/(.*)$ http://localhost:8888/$1 [P]
 
               <Directory /static/>
               Require all granted
               </Directory>
               '';
            }];
        };

        system.activationScripts = {
          django_init = {
            text = ''
              if [ \! -d /var/lib/django ]
              then
                mkdir /var/lib/django
              fi
            '';
            deps = [];
          };
        };
      };
    };
}
